@@ -104,7 +104,6 @@
 // the C standard does not, even though *any* practically useful machine
 // nowadays uses two's complement.
 
-#include "print.h"
 
 ///////////////////////////////////////////////////////////////////////////////
 // HEADER SECTION                                                            //
@@ -213,12 +212,12 @@ int main(int argc, char* argv[]) {
     FILE *f;
 
     if (argc < 2) {
-        printMessage("Usage: %s <input.jpg> [<output.ppm>]\n", argv[0]);
+        printf("Usage: %s <input.jpg> [<output.ppm>]\n", argv[0]);
         return 2;
     }
     f = fopen(argv[1], "rb");
     if (!f) {
-        print("Error opening the input file.\n");
+        printf("Error opening the input file.\n");
         return 1;
     }
     fseek(f, 0, SEEK_END);
@@ -231,14 +230,14 @@ int main(int argc, char* argv[]) {
     njInit();
     if (njDecode(buf, size)) {
         free((void*)buf);
-        printMessage("Error decoding the input file.\n");
+        printf("Error decoding the input file.\n");
         return 1;
     }
     free((void*)buf);
 
     f = fopen((argc > 2) ? argv[2] : (njIsColor() ? "nanojpeg_out.ppm" : "nanojpeg_out.pgm"), "wb");
     if (!f) {
-        printMessage("Error opening the output file.\n");
+        printf("Error opening the output file.\n");
         return 1;
     }
     fprintf(f, "P%d\n%d %d\n255\n", njIsColor() ? 6 : 5, njGetWidth(), njGetHeight());
@@ -599,7 +598,7 @@ NJ_INLINE void njDecodeDHT(void) {
             remain -= currcnt << (16 - codelen);
             if (remain < 0) njThrow(NJ_SYNTAX_ERROR);
             for (i = 0;  i < currcnt;  ++i) {
-                register unsigned char code = nj.pos[i];
+                unsigned char code = nj.pos[i];
                 for (j = spread;  j;  --j) {
                     vlc->bits = (unsigned char) codelen;
                     vlc->code = code;
@@ -841,9 +840,9 @@ NJ_INLINE void njConvert(void) {
         const unsigned char *pcr = nj.comp[2].pixels;
         for (yy = nj.height;  yy;  --yy) {
             for (x = 0;  x < nj.width;  ++x) {
-                register int y = py[x] << 8;
-                register int cb = pcb[x] - 128;
-                register int cr = pcr[x] - 128;
+                int y = py[x] << 8;
+                int cb = pcb[x] - 128;
+                int cr = pcr[x] - 128;
                 *prgb++ = njClip((y            + 359 * cr + 128) >> 8);
                 *prgb++ = njClip((y -  88 * cb - 183 * cr + 128) >> 8);
                 *prgb++ = njClip((y + 454 * cb            + 128) >> 8);
